@@ -91,6 +91,8 @@ def main():
         if (cli_args.username != None) and (cli_args.username != ""):
             if (cli_args.password == None) or (cli_args.password == ""):
                 common.fatal("Must specify both username AND password")
+            else:
+                user.login(cli_args.username, cli_args.password, True)
         vendor, name = common.parse_dep(cli_args.ip.lower())
         install.install_ip_and_deps(vendor, name, cli_args.is_global, cli_args.username, cli_args.password)
         common.exit()
