@@ -458,7 +458,14 @@ def compile_flist(vendor, name, flist_path, deps, sim_job, local, licensed=True)
     ip_dir_name = f"{vendor}__{name}"
     cmp_out_dir = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/"
     cmp_out = cmp_out_dir + ip_dir_name
-    sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd"
+    
+    if sim_job.is_regression:
+        ip_dir_name = f"{sim_job.vendor}__{sim_job.ip}__{sim_job.regression_name}"
+        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name)
+        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp)
+        sim_out  =        cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp
+    else:
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd"
     
     if sim_job.simulator != common.simulators_enum.METRICS:
         common.create_dir(cmp_out)
@@ -777,7 +784,7 @@ def do_simulate(ip, sim_job, wd):
             # TODO Implement waves file for vcs
             pass
         elif sim_job.simulator == common.simulators_enum.METRICS:
-            arg_list.append(f"-waves {test_result_dir}.vcd")
+            arg_list.append(f"-waves {test_result_dir}.fst")
         elif sim_job.simulator == common.simulators_enum.XCELIUM:
             # TODO Implement waves file for xcelium
             pass
@@ -861,6 +868,7 @@ def do_simulate(ip, sim_job, wd):
         arg_list.append(f"-image {ip.vendor}__{ip.name}")
         arg_list.append(f"-timescale {cfg.sim_timescale}")
         arg_list.append(f"-sv_lib %UVM_HOME%/src/dpi/libuvm_dpi.so")
+        arg_list.append(f"-sv_lib libcurl.so")
         #arg_list.append(f"-work {ip.vendor}__{ip.name}")
         
         so_libs = get_all_so_libs(ip, sim_job)
@@ -885,9 +893,9 @@ def do_simulate(ip, sim_job, wd):
         if not sim_job.dry_run:
             common.move_file(f"{cfg.project_dir}/_downloaded_{mtr_simulation_log_path}", simulation_log_path)
             if sim_job.waves:
-                common.remove_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd")
-                sim_job.bwrap_commands += launch_eda_bin(cfg.metrics_home + "/mdc", ["download", f"{test_result_dir}.vcd"], wd=cfg.project_dir, dry_run=sim_job.dry_run)
-                common.move_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd", f"{tests_results_path}/waves.vcd")
+                common.remove_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.fst")
+                sim_job.bwrap_commands += launch_eda_bin(cfg.metrics_home + "/mdc", ["download", f"{test_result_dir}.fst"], wd=cfg.project_dir, dry_run=sim_job.dry_run)
+                common.move_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd", f"{tests_results_path}/waves.fst")
         
     elif sim_job.simulator == common.simulators_enum.XCELIUM:
         arg_list += xcelium_default_simulation_args
